==> sslexplorer-0.2.13-src.tar.gz: sslexplorer-0.2.13/sslexplorer/src/com/sslexplorer/table/tags/PageSizeTag.java <==
/*
 *  SSL-Explorer
 *
 *  Copyright (C) 2003-2006 3SP LTD. All Rights Reserved
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation; either version 2 of
 *  the License, or (at your option) any later version.
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public
 *  License along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
			
package com.sslexplorer.table.tags;

import java.net.MalformedURLException;
import java.util.HashMap;
import java.util.Map;
import java.util.StringTokenizer;

import javax.servlet.jsp.JspException;
import javax.servlet.jsp.tagext.TagSupport;

import org.apache.struts.taglib.TagUtils;

import com.sslexplorer.core.CoreUtil;
import com.sslexplorer.core.tags.FormTag;
import com.sslexplorer.table.Pager;

public class PageSizeTag extends TagSupport {
    protected String pagerProperty = null;
    protected String pagerName = null;
    protected String action = null;
    protected String styleId = null;
    protected String styleClass = null;
    protected String style = null;
    protected String forward;
    protected String attributesName;
    protected String attributesProperties;
    protected String subForm = null;
    
    public final static String[] PAGE_SIZES = { "10", "20", "50", "100", "*" };

    public String getPagerName() {
        return (this.pagerName);
    }

    public void setAction(String action) {
        this.action = action;
    }

    public String getAction() {
        return action;
    }

    public String getForward() {
        return forward;
    }

    public void setForward(String forward) {
        this.forward = forward;
    }

    public void setPagerName(String pagerName) {
        this.pagerName = pagerName;
    }

    public void setSubForm(String subForm) {
    	this.subForm = subForm;
    }
    
    public String getSubForm() {
    	return subForm;
    }    
    public String getPagerProperty() {
        return (this.pagerProperty);
    }

    public void setPagerProperty(String pagerProperty) {
        this.pagerProperty = pagerProperty;
    }

    public void setStyle(String style) {
        this.style = style;
    }

    public String getStyle() {
        return style;
    }

    public void setStyleClass(String styleClass) {
        this.styleClass = styleClass;
    }

    public String getStyleClass() {
        return styleClass;
    }

    public void setStyleId(String styleId) {
        this.styleId = styleId;
    }

    public String getStyleId() {
        return styleId;
    }

    public void release() {
        super.release();
        pagerName = null;
        pagerProperty = null;
        action = null;
        styleId = null;
        styleClass = null;
        style = null;
        forward = null;
        attributesName = null;
        attributesProperties = null;
        subForm = null;

    }
    
    public void setAttributesName(String attributesName) {
        this.attributesName = attributesName;
    }

    public void setAttributesProperties(String attributesProperties) {
        this.attributesProperties = attributesProperties;
    }

    public int doEndTag() throws JspException {
        StringBuffer results = new StringBuffer();
        Pager pager = (Pager) TagUtils.getInstance().lookup(pageContext, pagerName, pagerProperty, null);
        if (pager != null && pager.getModel().getRowCount() >= Integer.parseInt(PAGE_SIZES[0])) {

            // Start of table
            results.append("<ul>");
            for (int i = 0; i < PAGE_SIZES.length; i++) {
                if(PAGE_SIZES[i].equals("*") || pager.getModel().getRowCount() >= Integer.parseInt(PAGE_SIZES[i])) {
                    results.append("<li><a href=\"");
                    results.append(getPageLink(PAGE_SIZES[i].equals("*") ? 0 : Integer.parseInt(PAGE_SIZES[i]), pager));
                    results.append("\"");
                    results.append(makeStyles(false));
                    results.append(">");
                    results.append(PAGE_SIZES[i]);
                    results.append("</a></li>");
                }
            }
            results.append("</ul>");
        }
        else {
            results.append("&nbsp;");
        }

        TagUtils.getInstance().write(pageContext, results.toString());
        return (EVAL_PAGE);

    }

    protected String getPageLink(int pageSize, Pager pager) {
        String url = null;
        try {
            Map params = new HashMap();
            params.put("pageSize", String.valueOf(pageSize));
            params.put("sortName", pager.getSortName());
            params.put("sortReverse", String.valueOf(pager.getSortReverse()));
            if(subForm!=null)
            	params.put("subForm", subForm);            
            if (pageSize == 0 || pageSize > pager.getFilteredRowCount()) {
                params.put("startRow", "0");
            }
            else {
                params.put("startRow", String.valueOf(pager.getStartRow()));                
            }            
            if(attributesName != null) {
                StringTokenizer t = new StringTokenizer(attributesProperties, ",");
                while (t.hasMoreTokens()) {
                    String attr = t.nextToken();
                    try {
                        params.put(attr, TagUtils.getInstance().lookup(pageContext, attributesName, attr, null).toString());
                    } catch (Exception e) {
                    }
                }
            }
            url = TagUtils.getInstance().computeURLWithCharEncoding(pageContext, forward, null, "", action, null, params, null,
                            false, false);
        } catch (MalformedURLException e) {
        }
        return (url);
    }

    protected String makeStyles(boolean disabled) throws JspException {
        StringBuffer results = new StringBuffer();
        String s = getStyleClass();
        if (s != null) {
            results.append(" class=\"");
            results.append(s);
            results.append("\"");
        }
        s = getStyle();
        if (s != null) {
            results.append(" style=\"");
            results.append(s);
            results.append("\"");
        }
        s = getStyleId();
        if (s != null) {
            results.append(" id=\"");
            results.append(s);
            results.append("\"");
        }
        return results.toString();
    }

    /*
     * (non-Javadoc)
     * 
     * @see javax.servlet.jsp.tagext.TagSupport#doStartTag()
     */
    public int doStartTag() throws JspException {
        if (subForm == null) {
            FormTag formTag = (FormTag) CoreUtil.getParentTagOfClass(FormTag.class, this);
            if (formTag != null) {
                subForm = formTag.getSubFormName();
            }
        }
        return SKIP_BODY;
    }

}

==> sslexplorer-0.2.15_01-src.tar.gz: sslexplorer-0.2.15_01/sslexplorer/src/com/sslexplorer/table/tags/PageSizeTag.java <==
/*
 *  SSL-Explorer
 *
 *  Copyright (C) 2003-2006 3SP LTD. All Rights Reserved
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation; either version 2 of
 *  the License, or (at your option) any later version.
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public
 *  License along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
			
package com.sslexplorer.table.tags;

import java.net.MalformedURLException;
import java.util.HashMap;
import java.util.Map;
import java.util.StringTokenizer;

import javax.servlet.jsp.JspException;
import javax.servlet.jsp.tagext.TagSupport;

import org.apache.struts.taglib.TagUtils;

import com.sslexplorer.core.CoreUtil;
import com.sslexplorer.core.tags.FormTag;
import com.sslexplorer.table.Pager;

public class PageSizeTag extends TagSupport {
    protected String pagerProperty = null;
    protected String pagerName = null;
    protected String action = null;
    protected String styleId = null;
    protected String styleClass = null;
    protected String style = null;
    protected String forward;
    protected String attributesName;
    protected String attributesProperties;
    protected String subForm = null;
    
    public final static String[] PAGE_SIZES = { "10", "20", "50", "100", "*" };

    public String getPagerName() {
        return (this.pagerName);
    }

    public void setAction(String action) {
        this.action = action;
    }

    public String getAction() {
        return action;
    }

    public String getForward() {
        return forward;
    }

    public void setForward(String forward) {
        this.forward = forward;
    }

    public void setPagerName(String pagerName) {
        this.pagerName = pagerName;
    }

    public void setSubForm(String subForm) {
    	this.subForm = subForm;
    }
    
    public String getSubForm() {
    	return subForm;
    }    
    public String getPagerProperty() {
        return (this.pagerProperty);
    }

    public void setPagerProperty(String pagerProperty) {
        this.pagerProperty = pagerProperty;
    }

    public void setStyle(String style) {
        this.style = style;
    }

    public String getStyle() {
        return style;
    }

    public void setStyleClass(String styleClass) {
        this.styleClass = styleClass;
    }

    public String getStyleClass() {
        return styleClass;
    }

    public void setStyleId(String styleId) {
        this.styleId = styleId;
    }

    public String getStyleId() {
        return styleId;
    }

    public void release() {
        super.release();
        pagerName = null;
        pagerProperty = null;
        action = null;
        styleId = null;
        styleClass = null;
        style = null;
        forward = null;
        attributesName = null;
        attributesProperties = null;
        subForm = null;

    }
    
    public void setAttributesName(String attributesName) {
        this.attributesName = attributesName;
    }

    public void setAttributesProperties(String attributesProperties) {
        this.attributesProperties = attributesProperties;
    }

    public int doEndTag() throws JspException {
        StringBuffer results = new StringBuffer();
        Pager pager = (Pager) TagUtils.getInstance().lookup(pageContext, pagerName, pagerProperty, null);
        if (pager != null && pager.getModel().getRowCount() >= Integer.parseInt(PAGE_SIZES[0])) {

            // Start of table
            results.append("<ul>");
            for (int i = 0; i < PAGE_SIZES.length; i++) {
                if(PAGE_SIZES[i].equals("*") || pager.getModel().getRowCount() >= Integer.parseInt(PAGE_SIZES[i])) {
                    results.append("<li><a href=\"");
                    results.append(getPageLink(PAGE_SIZES[i].equals("*") ? 0 : Integer.parseInt(PAGE_SIZES[i]), pager));
                    results.append("\"");
                    results.append(makeStyles(false));
                    results.append("><div class=\"pageSize\">");
                    results.append(PAGE_SIZES[i]);
                    results.append("</div></a></li>");
                }
            }
            results.append("</ul>");
        }
        else {
            results.append("&nbsp;");
        }

        TagUtils.getInstance().write(pageContext, results.toString());
        return (EVAL_PAGE);

    }

    protected String getPageLink(int pageSize, Pager pager) {
        String url = null;
        try {
            Map params = new HashMap();
            params.put("pageSize", String.valueOf(pageSize));
            params.put("sortName", pager.getSortName());
            params.put("sortReverse", String.valueOf(pager.getSortReverse()));
            if(subForm!=null)
            	params.put("subForm", subForm);            
            if (pageSize == 0 || pageSize > pager.getFilteredRowCount()) {
                params.put("startRow", "0");
            }
            else {
                params.put("startRow", String.valueOf(pager.getStartRow()));                
            }            
            if(attributesName != null) {
                StringTokenizer t = new StringTokenizer(attributesProperties, ",");
                while (t.hasMoreTokens()) {
                    String attr = t.nextToken();
                    try {
                        params.put(attr, TagUtils.getInstance().lookup(pageContext, attributesName, attr, null).toString());
                    } catch (Exception e) {
                    }
                }
            }
            url = TagUtils.getInstance().computeURLWithCharEncoding(pageContext, forward, null, "", action, null, params, null,
                            false, false);
        } catch (MalformedURLException e) {
        }
        return (url);
    }

    protected String makeStyles(boolean disabled) throws JspException {
        StringBuffer results = new StringBuffer();
        String s = getStyleClass();
        if (s != null) {
            results.append(" class=\"");
            results.append(s);
            results.append("\"");
        }
        s = getStyle();
        if (s != null) {
            results.append(" style=\"");
            results.append(s);
            results.append("\"");
        }
        s = getStyleId();
        if (s != null) {
            results.append(" id=\"");
            results.append(s);
            results.append("\"");
        }
        return results.toString();
    }

    /*
     * (non-Javadoc)
     * 
     * @see javax.servlet.jsp.tagext.TagSupport#doStartTag()
     */
    public int doStartTag() throws JspException {
        // JDR change so that task processes return to the correct location
        FormTag formTag = (FormTag) CoreUtil.getParentTagOfClass(FormTag.class, this);
        if (formTag != null) {
            subForm = formTag.getSubFormName();
        }
        else {
            subForm = null;
        }
        return SKIP_BODY;
    }

}
